==> kdenetwork-3.4.2.tar.bz2: kdenetwork-3.4.2/kopete/protocols/jabber/libiris/cutestuff/network/socks.h <==
/*
 * socks.h - SOCKS5 TCP proxy client/server
 * Copyright (C) 2003  Justin Karneges
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef CS_SOCKS_H
#define CS_SOCKS_H

#include"bytestream.h"

// CS_NAMESPACE_BEGIN

class QHostAddress;
class SocksServer;

class SocksClient : public ByteStream
{
	Q_OBJECT
public:
	enum Error { ErrConnectionRefused = ErrCustom, ErrHostNotFound, ErrProxyConnect, ErrProxyNeg, ErrProxyAuth };
	enum Method { AuthNone=0x0001, AuthUsername=0x0002 };
	SocksClient(QObject *parent=0);
	SocksClient(int, QObject *parent=0);
	~SocksClient();

	bool isIncoming() const;

	// outgoing
	void setAuth(const QString &user, const QString &pass="");
	void connectToHost(const QString &proxyHost, int proxyPort, const QString &host, int port);

	// incoming
	void chooseMethod(int);
	void authGrant(bool);
	void requestGrant(bool);

	// from ByteStream
	bool isOpen() const;
	void close();
	void write(const QByteArray &);
	QByteArray read(int bytes=0);
	int bytesAvailable() const;
	int bytesToWrite() const;

	QHostAddress peerAddress() const;
	Q_UINT16 peerPort() const;

signals:
	// outgoing
	void connected();

	// incoming
	void incomingMethods(int);
	void incomingAuth(const QString &user, const QString &pass);
	void incomingRequest(const QString &host, int port);

private slots:
	void sock_connected();
	void sock_connectionClosed();
	void sock_delayedCloseFinished();
	void sock_readyRead();
	void sock_bytesWritten(int);
	void sock_error(int);
	void serve();

private:
	class Private;
	Private *d;

	void init();
	void reset(bool clear=false);
	void do_request();
	void processOutgoing(const QByteArray &);
	void processIncoming(const QByteArray &);
	void continueIncoming();
	void writeData(const QByteArray &a);
};

class SocksServer : public QObject
{
	Q_OBJECT
public:
	SocksServer(QObject *parent=0);
	~SocksServer();

	bool isActive() const;
	bool listen(Q_UINT16 port);
	void stop();
	int port() const;
	QHostAddress address() const;
	SocksClient *takeIncoming();

signals:
	void incomingReady();

private slots:
	void connectionReady(int);
	void connectionError();

private:
	class Private;
	Private *d;
};

// CS_NAMESPACE_END

#endif

==> kdenetwork-4.1.3.tar.bz2: kdenetwork-4.1.3/kopete/protocols/jabber/libiris/cutestuff/network/socks.h <==
/*
 * socks.h - SOCKS5 TCP proxy client/server
 * Copyright (C) 2003  Justin Karneges
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef CS_SOCKS_H
#define CS_SOCKS_H

#include "bytestream.h"
#include "cutestuff_export.h"
// CS_NAMESPACE_BEGIN

class QHostAddress;
class SocksClient;
class SocksServer;

class CUTESTUFF_EXPORT SocksUDP : public QObject
{
	Q_OBJECT
public:
	~SocksUDP();

	void change(const QString &host, int port);
	void write(const QByteArray &data);

signals:
	void packetReady(const QByteArray &data);

private slots:
	void sn_activated(int);

private:
	class Private;
	Private *d;

	friend class SocksClient;
	SocksUDP(SocksClient *sc, const QString &host, int port, const QHostAddress &routeAddr, int routePort);
};

class CUTESTUFF_EXPORT SocksClient : public ByteStream
{
	Q_OBJECT
public:
	enum Error { ErrConnectionRefused = ErrCustom, ErrHostNotFound, ErrProxyConnect, ErrProxyNeg, ErrProxyAuth };
	enum Method { AuthNone=0x0001, AuthUsername=0x0002 };
	enum Request { ReqConnect, ReqUDPAssociate };
	SocksClient(QObject *parent=0);
	SocksClient(int, QObject *parent=0);
	~SocksClient();

	bool isIncoming() const;

	// outgoing
	void setAuth(const QString &user, const QString &pass="");
	void connectToHost(const QString &proxyHost, int proxyPort, const QString &host, int port, bool udpMode=false);

	// incoming
	void chooseMethod(int);
	void authGrant(bool);
	void requestDeny();
	void grantConnect();
	void grantUDPAssociate(const QString &relayHost, int relayPort);

	// from ByteStream
	bool isOpen() const;
	void close();
	void write(const QByteArray &);
	QByteArray read(int bytes=0);
	int bytesAvailable() const;
	int bytesToWrite() const;

	// remote address
	QHostAddress peerAddress() const;
	Q_UINT16 peerPort() const;

	// udp
	QString udpAddress() const;
	Q_UINT16 udpPort() const;
	SocksUDP *createUDP(const QString &host, int port, const QHostAddress &routeAddr, int routePort);

signals:
	// outgoing
	void connected();

	// incoming
	void incomingMethods(int);
	void incomingAuth(const QString &user, const QString &pass);
	void incomingConnectRequest(const QString &host, int port);
	void incomingUDPAssociateRequest();

private slots:
	void sock_connected();
	void sock_connectionClosed();
	void sock_delayedCloseFinished();
	void sock_readyRead();
	void sock_bytesWritten(int);
	void sock_error(int);
	void serve();

private:
	class Private;
	Private *d;

	void init();
	void reset(bool clear=false);
	void do_request();
	void processOutgoing(const QByteArray &);
	void processIncoming(const QByteArray &);
	void continueIncoming();
	void writeData(const QByteArray &a);
};

class CUTESTUFF_EXPORT SocksServer : public QObject
{
	Q_OBJECT
public:
	SocksServer(QObject *parent=0);
	~SocksServer();

	bool isActive() const;
	bool listen(Q_UINT16 port, bool udp=false);
	void stop();
	int port() const;
	QHostAddress address() const;
	SocksClient *takeIncoming();

	void writeUDP(const QHostAddress &addr, int port, const QByteArray &data);

signals:
	void incomingReady();
	void incomingUDP(const QString &host, int port, const QHostAddress &addr, int sourcePort, const QByteArray &data);

private slots:
	void connectionReady(int);
	void connectionError();
	void sn_activated(int);

private:
	class Private;
	Private *d;
};

// CS_NAMESPACE_END

#endif
